aboutsummaryrefslogtreecommitdiffstats
path: root/tools/search_bing.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tools/search_bing.sh')
-rwxr-xr-xtools/search_bing.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/search_bing.sh b/tools/search_bing.sh
index 4ab1117..dd60e0c 100755
--- a/tools/search_bing.sh
+++ b/tools/search_bing.sh
@@ -5,15 +5,15 @@ set -e
# Use this when you need current information or feel a search could provide a better answer.
# @env BING_API_KEY! The api key
# @env BING_MAX_RESULTS=5 The max results to return.
# @option --query! The query to search for.
main() {
encoded_query="$(jq -nr --arg q "$argc_query" '$q|@uri')"
- url="https://api.bing.microsoft.com/v7.0/search?q=$encoded_query&mkt=en-us&textdecorations=true&textformat=raw&count=$BING_MAX_RESULTS&offset=0"
+ url="https://api.bing.microsoft.com/v7.0/search?q=$encoded_query&mkt=en-us&textdecorations=true&textformat=raw&count=$SEARCH_MAX_RESULTS&offset=0"
curl -fsSL "$url" \
-H "Ocp-Apim-Subscription-Key: $BING_API_KEY" | \
- jq '[.webPages.value[] | {name: .name, url: .url, snippet: .snippet}]' \
+ jq '[.webPages.value[] | {link: .url, title: .name, snippet: .snippet}]' \
>> "$LLM_OUTPUT"
}
@@ -5,15 +5,15 @@ set -e
# Use this when you need current information or feel a search could provide a better answer.
# @env BING_API_KEY! The api key
-# @env BING_MAX_RESULTS=5 The max results to return.
+# @env SEARCH_MAX_RESULTS=5 The max results to return.
# @option --query! The query to search for.
main() {